import React, {useEffect, useState, useCallback} from "react";
import {connect, useDispatch} from "react-redux";
import {Card, Col, Row, Button} from "react-bootstrap";
import {Link} from "react-router-dom";
import {actions as cartActions} from "@redux/cartRedux";
import {actions as favoriteActions} from "@redux/favoriteRedux";
import favoriteServices from "services/favouriteServices";
import {isUserLoggedIn} from "services/userServices";
import Rating from "react-rating";
import SuperSaleProducts from "components/ourOffers/superSale";
import {actions as brandActions} from "@redux/brandRedux";
import {Helmet} from "react-helmet";
import SpinnerLocal from "../../components/spinner";


const AllBrand = (props) => {

    const dispatch = useDispatch();
    const [brandData, setBrandData] = useState([]);
    const [seeAllBtn, setSeeAllBtn] = useState(false);
    const [showBrandIndex, setShowBrandIndex] = useState(-1);

    useEffect(() => {
        dispatch(brandActions.getAllBrands(12));
    }, [dispatch]);

    if (
        props.brand.brandsLoading &&
        props.brand.brands.length === 0
    ) {
        return (
            <SpinnerLocal height="75vh"/>
        );
    }

    return (
        <div>
            <Helmet>
                <title> Genx | All Brand </title>
                <meta name="description" content="Shopstick Home page"/>
            </Helmet>
            <div className="explore-categories" style={{paddingTop: "10px"}}>
                <div className="regular-offer">
                    <Row className="top">
                        <Col xl={4} lg={3} md={6} sm={12} xs={12}>
                            <p className="top-title">
                                Our Brands <br/>
                                <span style={{fontSize: "12px", fontWeight: 500}}>
              </span>
                            </p>
                        </Col>
                    </Row>

                    <Row className="responsive-card">
                        {props.brand.brands.length > 0 && props.brand.brands.map((brand, index) => (
                            <Col
                                xl={3} lg={4} md={6} sm={12} xs={12}
                                // onMouseEnter={() => {
                                //   setShowBrandIndex(index);
                                // }}
                                // onMouseLeave={() => setShowBrandIndex(-1)}
                            >
                                <Link to={"/brandProducts/" + brand.name}>
                                    <Card className="explore-slider flex justify-content-center"
                                          style={{
                                              width: "auto",
                                              height: "200px",
                                              padding: "20px",
                                              cursor: 'pointer',
                                          }}>
                                        <img style={{maxWidth: '100%', maxHeight: '100%'}} src={brand.logo_image ? brand.logo_image : '/images/health.png'}/>
                                    </Card>
                                </Link>


                                {/*{showBrandIndex === index ? (*/}
                                {/*    <Card className="explore-slider" style={{width:"auto", height:"200px", padding:"10px"}}>*/}
                                {/*      <div className="slider-image">*/}
                                {/*        <img*/}
                                {/*          src={brand.banner_image ? brand.banner_image:'/images/health.png'}*/}
                                {/*          className="target-image"*/}
                                {/*          alt={brand.name?brand.name:'brands_name'}*/}
                                {/*        />*/}
                                {/*      </div>*/}
                                {/*      <div*/}
                                {/*        className="button"*/}
                                {/*        onMouseEnter={() => {*/}
                                {/*          setSeeAllBtn(true);*/}
                                {/*        }}*/}
                                {/*        onMouseLeave={() => setSeeAllBtn(false)}*/}
                                {/*      >*/}
                                {/*        {seeAllBtn ? (*/}
                                {/*          <Link to={"/brandProducts/" + brand.name}>*/}
                                {/*            <button className="see-all-btn">*/}
                                {/*              {" "}*/}
                                {/*              View Products &nbsp; &nbsp;{" "}*/}
                                {/*              <img src="/images/arrow-right-white.png" />*/}
                                {/*            </button>*/}
                                {/*          </Link>*/}
                                {/*        ) : (*/}
                                {/*          <Link to={"/brandProducts/" + brand.name}>*/}
                                {/*            <button className="see-all-btn">*/}
                                {/*              {" "}*/}
                                {/*              View Products &nbsp; &nbsp;{" "}*/}
                                {/*              <img src="/images/red-arrow-right.png" />*/}
                                {/*            </button>*/}
                                {/*          </Link>*/}
                                {/*        )}*/}
                                {/*      </div>*/}
                                {/*    </Card>*/}
                                {/*  ) : (*/}
                                {/*    <Card className="explore-slider px-10px" style={{width:"auto", height:"200px",padding:"10px"}}>*/}
                                {/*      <img*/}
                                {/*        src="/images/health.png"*/}
                                {/*        className="card-category-image"*/}
                                {/*        alt="category"*/}
                                {/*      />*/}
                                {/*      <Card.Body>*/}
                                {/*        <Card.Text className="card-text">*/}

                                {/*        </Card.Text>*/}
                                {/*      </Card.Body>*/}
                                {/*    </Card>*/}
                                {/*  )}*/}
                            </Col>
                        ))}
                    </Row>


                    {/* Load more */}
                    {!props.brand.brandsLoading &&
                    props.brand.brandsInfo.current_page &&
                    props.brand.brandsInfo.current_page !== props.brand.brandsInfo.last_page && (
                        <Row>
                            <Col className="more-product">
                                <Button
                                    className="load-more"
                                    variant="primary"
                                    onClick={() => {
                                        dispatch(brandActions.getAllBrands(12, props.brand.brandsInfo.current_page + 1));
                                    }}
                                >
                                    <span className="btn-text">Load More</span>
                                </Button>
                            </Col>
                        </Row>
                    )}

                    {/* loading... */}
                    {props.brand.brandsLoading && (
                        <SpinnerLocal height="15vh"/>
                    )}


                </div>
            </div>
        </div>
    );
};

const mapStateToProps = ({brand, cart, favorite, user}) => {
    return {brand, cart: cart.cart, favorite, user};
};
export default connect(mapStateToProps)(AllBrand);
